
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card";
import { Button } from "@/components/ui/button";
import { ImageIcon, FileText, Code, ChevronRight, MessageSquareText, BookOpen } from "lucide-react";
import { useNavigate } from "react-router-dom";
import { HeroIllustration } from "@/components/HeroIllustration";
import { Separator } from "@/components/ui/separator";
import FeatureSection from "@/components/FeatureSection";
import { useTranslation } from "@/hooks/use-translation";

const Index = () => {
  const navigate = useNavigate();
  const { t } = useTranslation();

  const features = [
    {
      title: t("tools.imageEditor.title"),
      description: t("tools.imageEditor.description"),
      icon: ImageIcon,
      path: "/image-editor",
      color: "bg-blue-500"
    },
    {
      title: t("tools.documentViewer.title"),
      description: t("tools.documentViewer.description"),
      icon: FileText,
      path: "/document-viewer",
      color: "bg-green-500"
    },
    {
      title: t("tools.codeFormatter.title"),
      description: t("tools.codeFormatter.description"),
      icon: Code,
      path: "/code-formatter",
      color: "bg-purple-500"
    }
  ];

  const blogPosts = [
    {
      title: t("blog.posts.1.title"),
      excerpt: t("blog.posts.1.excerpt"),
      date: t("blog.posts.1.date"),
      category: t("blog.posts.1.category"),
      readTime: t("blog.posts.1.readTime")
    },
    {
      title: t("blog.posts.2.title"),
      excerpt: t("blog.posts.2.excerpt"),
      date: t("blog.posts.2.date"),
      category: t("blog.posts.2.category"),
      readTime: t("blog.posts.2.readTime")
    },
    {
      title: t("blog.posts.3.title"),
      excerpt: t("blog.posts.3.excerpt"),
      date: t("blog.posts.3.date"),
      category: t("blog.posts.3.category"),
      readTime: t("blog.posts.3.readTime")
    }
  ];

  const faqs = [
    {
      question: t("faq.items.1.question"),
      answer: t("faq.items.1.answer")
    },
    {
      question: t("faq.items.2.question"),
      answer: t("faq.items.2.answer")
    },
    {
      question: t("faq.items.3.question"),
      answer: t("faq.items.3.answer")
    },
    {
      question: t("faq.items.4.question"),
      answer: t("faq.items.4.answer")
    }
  ];

  return (
    <>
      {/* Hero Section - Optimizado para LCP */}
      <section className="py-16 md:py-24 px-4 overflow-hidden">
        <div className="container mx-auto">
          <div className="flex flex-col md:flex-row items-center gap-10">
            <div className="md:w-1/2 space-y-6">
              <div className="space-y-4">
                {/* Se eliminó el degradado del texto para mejorar el LCP - se usará color sólido */}
                <h1 
                  className="text-4xl md:text-5xl lg:text-6xl font-bold leading-tight text-primary"
                  id="hero-title"
                  // Importante: fetchpriority alto para el LCP
                >
                  {t("hero.title")}
                </h1>
                <p className="text-xl text-muted-foreground max-w-xl">
                  {t("hero.description")}
                </p>
              </div>
              <div className="flex flex-wrap gap-4">
                <Button size="lg" onClick={() => navigate("/image-editor")} className="shadow-lg">
                  {t("hero.cta")} <ChevronRight className="ml-2 h-4 w-4" />
                </Button>
                <Button size="lg" variant="outline" onClick={() => document.getElementById('features')?.scrollIntoView({ behavior: 'smooth' })}>
                  {t("hero.exploreTools")}
                </Button>
              </div>
              <div className="pt-4">
                <p className="text-sm text-muted-foreground">
                  {t("hero.privacyNote")}
                </p>
              </div>
            </div>
            <div className="md:w-1/2 flex justify-center">
              {/* Ilustración optimizada con loading eager y fetchpriority high */}
              <HeroIllustration className="max-w-full h-auto w-full max-h-[500px]" />
            </div>
          </div>
        </div>
      </section>

      {/* Features Section */}
      <section id="features" className="py-16 px-4 bg-muted/30">
        <div className="container mx-auto">
          <h2 className="text-3xl font-bold text-center mb-12">{t("tools.title")}</h2>
          <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
            {features.map((feature) => (
              <Card key={feature.title} className="card-effect border-t-4" style={{ borderTopColor: `var(--${feature.color.replace('bg-', '')})` }}>
                <CardHeader>
                  <div className={`w-12 h-12 rounded-lg flex items-center justify-center ${feature.color} mb-4`}>
                    <feature.icon className="h-6 w-6 text-white" />
                  </div>
                  <CardTitle>{feature.title}</CardTitle>
                  <CardDescription>{feature.description}</CardDescription>
                </CardHeader>
                <CardContent>
                  <Button 
                    onClick={() => navigate(feature.path)}
                    className="w-full"
                  >
                    {t("tools.access")}
                  </Button>
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* Feature Details Section */}
      <FeatureSection />

      {/* Call to Action */}
      <section className="py-20 px-4">
        <div className="container mx-auto">
          <div className="bg-gradient-to-r from-accent/80 to-primary/80 rounded-xl p-8 shadow-lg text-white">
            <div className="flex flex-col md:flex-row items-start md:items-center justify-between gap-6">
              <div>
                <h2 className="text-2xl font-bold mb-3">{t("cta.title")}</h2>
                <p className="max-w-2xl opacity-90">
                  {t("cta.description")}
                </p>
              </div>
              <Button 
                variant="secondary" 
                size="lg"
                className="text-primary font-medium"
                onClick={() => navigate(features[0].path)}
              >
                {t("cta.button")}
              </Button>
            </div>
          </div>
        </div>
      </section>

      {/* Blog Section */}
      <section id="blog" className="py-16 px-4 bg-muted/30">
        <div className="container mx-auto">
          <div className="text-center mb-12">
            <h2 className="text-3xl font-bold mb-3">{t("blog.title")}</h2>
            <p className="text-muted-foreground max-w-2xl mx-auto">
              {t("blog.description")}
            </p>
          </div>
          
          <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
            {blogPosts.map((post, index) => (
              <Card key={index} className="overflow-hidden hover:shadow-lg transition-shadow">
                <div className={`h-3 ${['bg-blue-500', 'bg-green-500', 'bg-purple-500'][index % 3]}`}></div>
                <CardHeader>
                  <div className="flex justify-between items-center text-sm text-muted-foreground mb-2">
                    <span>{post.category}</span>
                    <span>{post.date}</span>
                  </div>
                  <CardTitle className="line-clamp-2">{post.title}</CardTitle>
                </CardHeader>
                <CardContent className="space-y-4">
                  <p className="text-muted-foreground line-clamp-3">{post.excerpt}</p>
                  <div className="flex justify-between items-center">
                    <span className="text-sm text-muted-foreground">{post.readTime}</span>
                    <Button variant="ghost" size="sm" className="text-primary">
                      {t("blog.readMore")} <ChevronRight className="h-4 w-4 ml-1" />
                    </Button>
                  </div>
                </CardContent>
              </Card>
            ))}
          </div>
          
          <div className="text-center mt-10">
            <Button variant="outline" onClick={() => navigate("/blog")}>
              {t("blog.viewMore")}
            </Button>
          </div>
        </div>
      </section>

      {/* FAQ Section */}
      <section id="faq" className="py-16 px-4">
        <div className="container mx-auto">
          <div className="text-center mb-12">
            <h2 className="text-3xl font-bold mb-3">{t("faq.title")}</h2>
            <p className="text-muted-foreground max-w-2xl mx-auto">
              {t("faq.description")}
            </p>
          </div>
          
          <div className="max-w-3xl mx-auto divide-y">
            {faqs.map((faq, index) => (
              <div key={index} className="py-6">
                <h3 className="text-xl font-semibold mb-3">{faq.question}</h3>
                <p className="text-muted-foreground">{faq.answer}</p>
              </div>
            ))}
          </div>
          
          <div className="text-center mt-10">
            <p className="text-muted-foreground mb-4">
              {t("faq.moreQuestions")}
            </p>
            <Button onClick={() => navigate("/contact")}>
              {t("faq.contactUs")}
            </Button>
          </div>
        </div>
      </section>
    </>
  );
};

export default Index;
